package com.ruoyi.web.service;

import com.alibaba.fastjson2.JSONObject;
import com.ruoyi.web.bo.ResponseBo;
import com.ruoyi.web.config.ConfigComponent;
import com.ruoyi.web.config.RestUtil;
import com.ruoyi.web.entity.GatherData;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.math.RoundingMode;

/**
 * 钦州联运中心智慧闸口接口调用-业务处理
 */
@Service
@Slf4j
public class IntermodalTransporService {
    @Autowired
    private ConfigComponent configComponent;


    /** 钦州闸口识别对接接口 */
    public ResponseBo gateIdentify(GatherData gatherData) {
        HttpHeaders headers = new HttpHeaders();
        headers.setContentType(MediaType.parseMediaType(MediaType.APPLICATION_JSON_VALUE));
        ResponseBo res = new ResponseBo();

        //车牌号(必输)
        String plateNum = gatherData.getVE_LICENSE_NO();
        //过磅重量NUMBER(18,3)(必输)
        //读取到的地磅重量——>KG转换为吨
        BigDecimal grossWt = new BigDecimal(gatherData.getGROSS_WT());
        grossWt = grossWt.divide(BigDecimal.valueOf(1000),2, RoundingMode.HALF_UP);
        double weight = grossWt.doubleValue();
        //进出信息，in 进 out 出
        String laneMode = "I".equalsIgnoreCase(gatherData.getI_E_FLAG()) ? "in" : "out";
        //前箱箱号
        String boxNo = gatherData.getCntrnoF();
        //后箱箱号
        String boxNoSecond = gatherData.getCntrnoA();
        //重磅/空磅:E/F
        String weightType = "";

        //请求地址
        String url = configComponent.getGateIdentifyUrl();
        //请求体
        String body = "{\"appid\":\""+configComponent.getAppid()+"\"," +
                "\"data\":{\"plateNum\":\""+plateNum+"\",\"weight\":\""+weight+"\",\"laneMode\":\""+laneMode+"\"," +
                "\"boxNo\":\""+boxNo+"\",\"boxNoSecond\":\""+boxNoSecond+"\",\"weightType\":\""+weightType+"\"}}";
        JSONObject params = JSONObject.parseObject(body);
        log.info("钦州闸口识别对接接口url:{}",url);
        log.info("钦州闸口识别对接接口params:{}",params);
        try {
            JSONObject jsonObject = RestUtil.post(url, headers, params);
            log.info("钦州闸口识别对接接口返回结果:{}",jsonObject);
            if(jsonObject != null && jsonObject.toString().contains("success") && jsonObject.getBoolean("success")) {
                res.setCode(200);
                res.setMsg(jsonObject.getString("message"));
            } else {
                res.setCode(500);
                res.setMsg(jsonObject.getString("message"));
            }
        } catch (Exception e) {
            log.info("钦州闸口识别对接接口报错:{}",e.getMessage());
            res.setCode(500);
            res.setMsg(e.getMessage());
            return res;
        }

        res.setCode(200);
        res.setMsg("请通行");

        return res;
    }


}
